summaryrefslogtreecommitdiffstats
path: root/client/components/lists/listHeader.js
diff options
context:
space:
mode:
authorLauri Ojansivu <x@xet7.org>2020-05-14 01:04:52 +0300
committerLauri Ojansivu <x@xet7.org>2020-05-14 01:04:52 +0300
commitea74a34d72fb0f33909858a640dbcd3a5fda5b7f (patch)
tree697e686168f41fef0da5903722bbda98e17d0ff0 /client/components/lists/listHeader.js
parent28cffc43287d154ff4dafc78766401449fb13746 (diff)
downloadwekan-ea74a34d72fb0f33909858a640dbcd3a5fda5b7f.tar.gz
wekan-ea74a34d72fb0f33909858a640dbcd3a5fda5b7f.tar.bz2
wekan-ea74a34d72fb0f33909858a640dbcd3a5fda5b7f.zip
Add popup and changelog for linked card fixes.
Diffstat (limited to 'client/components/lists/listHeader.js')
-rw-r--r--client/components/lists/listHeader.js12
1 files changed, 11 insertions, 1 deletions
diff --git a/client/components/lists/listHeader.js b/client/components/lists/listHeader.js
index a839bb72..7cd4309f 100644
--- a/client/components/lists/listHeader.js
+++ b/client/components/lists/listHeader.js
@@ -238,9 +238,19 @@ Template.listMorePopup.events({
allCardIds.map(_id => Cards.remove(_id));
Lists.remove(this._id);
} else {
// TODO popup with a hint that the list cannot be deleted as there are
// linked cards. We can adapt the query above so we can list the linked
// cards.
+ // Related:
+ // client/components/cards/cardDetails.js about line 969
+ // https://github.com/wekan/wekan/issues/2785
+ const message = `${TAPi18n.__(
+ 'delete-linked-cards-before-this-list',
+ )} linkedId: ${
+ this._id
+ } at client/components/lists/listHeader.js and https://github.com/wekan/wekan/issues/2785`;
+ alert(message);
}
Utils.goBoardId(this.boardId);
}),
@@ -238,9 +238,19 @@ Template.listMorePopup.events({
Lists.remove(this._id);
} else {
- // TODO popup with a hint that the list cannot be deleted as there are
+ // TODO: Figure out more informative message.
+ // Popup with a hint that the list cannot be deleted as there are
// linked cards. We can adapt the query above so we can list the linked
// cards.